@@ -22,11 +22,9 @@ __summary__ = ("cryptography is a package designed to expose cryptographic "
                "recipes and primitives to Python developers.")
 __uri__ = "https://github.com/pyca/cryptography"
 
-__version__ = "0.1"
+__version__ = "0.2"
 
-__author__ = ("Alex Gaynor, Hynek Schlawack, Donald Stufft, "
-              "Laurens Van Houtven, Jean-Paul Calderone, Christian Heimes, "
-              "Paul Kehrer, and individual contributors.")
+__author__ = "The cryptography developers"
 __email__ = "cryptography-dev@python.org"
 
 __license__ = "Apache License, Version 2.0"
